@@ -303,7 +303,7 @@ int main (int argc, char *argv[])
 	int i, length, size;
 	char *input, *output;
 
-	if (strcmp (argv[1], "-h") == 0 ||
+	if (argc <= 2 || strcmp (argv[1], "-h") == 0 ||
 	    strcmp (argv[1], "--help") == 0) {
 		g_print ("Usage: %s [-s <size>] <input> <output> [backend options]\n", argv[0]);
 		return -1;
@@ -357,7 +357,6 @@ int main (int argc, char *argv[])
 				save_still_pixbuf (pixbuf,
 						output, input, size);
 				gdk_pixbuf_unref (pixbuf);
-				g_error_free (err);
 				exit (0);
 			}
 			g_print ("totem-video-thumbnailer couln't open file '%s'\n"
